@@ -36,6 +36,11 @@
 #' }
 #' \dontshow{randnet.test(net, iter = 1, cores = 2)}
 #' 
+#' @references 
+#' Viger, F., & Latapy, M. (2016).
+#' Efficient and simple generation of random simple connected graphs with prescribed degree sequence.
+#' \emph{Journal of Complex Networks}, \emph{4}, 15-37.
+#' 
 #' @author Alexander Christensen <alexpaulchristensen@gmail.com>
 #' 
 #' @importFrom stats dnorm
@@ -57,23 +62,14 @@ randnet.test <- function (..., iter, cores)
     name <- name[-which(name=="list")]
     
     #Create list of input
-    datalist <- list(...)
+    listdata <- list(...)
     
-    #Number of nodes
-    nodes <- list()
+    #Initialize data list
+    data.list <- vector("list", length = length(name))
     
-    for(i in 1:length(datalist))
-    {nodes[[i]] <- ncol(datalist[[i]])}
-    
-    #Make diagonals zero
-    for(i in 1:length(datalist))
-    {diag(datalist[[i]]) <- 0}
-    
-    #Number of edges
-    edges <- list()
-    
-    for(i in 1:length(datalist))
-    {edges[[i]] <- sum(colSums(NetworkToolbox::binarize(datalist[[i]])))/2}
+    for(i in 1:length(name))
+        for(j in 1:iter)
+            {data.list[[i]][[j]] <- listdata[[i]]}
     
     #Initialize random networks list
     rand.list <- vector("list", length = length(name))
@@ -82,28 +78,15 @@ randnet.test <- function (..., iter, cores)
     #Message for begin random networks
     message("Generating random networks...", appendLF = FALSE)
     
-    for(i in 1:length(datalist))
-    {
-        #Initialize count
-        count <- 0
-        
-        repeat{
-            
-            #Increase count
-            count <- count + 1
-            
-            #Generate random network
-            rand.list[[i]][[count]] <- NetworkToolbox::randnet(nodes[[i]], edges[[i]])
-            
-            #Break out of repeat when
-            #count reaches iter
-            if(count == iter)
-            {break}
-        }
-    }
+    #Parallel processing
+    cl <- parallel::makeCluster(cores)
     
-    #Message for end of random networks
-    message("done", appendLF = TRUE)
+    #Export variables
+    parallel::clusterExport(cl, c("data.list", "rand.list"), envir = environment())
+    
+    #Compute random networks
+    for(i in 1:length(data.list))
+    {rand.list[[i]] <- pbapply::pblapply(X = data.list[[i]], FUN = function(X){randnet(A = X)}, cl = cl)}
     
     #Message for begin of network measures
     message("Computing network measures...\n", appendLF = FALSE)
@@ -112,13 +95,10 @@ randnet.test <- function (..., iter, cores)
     net.meas <- vector("list", length = length(name))
     names(net.meas) <- name
     
-    #Parallel processing
-    cl <- parallel::makeCluster(cores)
-    
     #Export variables
-    parallel::clusterExport(cl, c("rand.list", "net.meas"), envir = environment())
+    parallel::clusterExport(cl, c("net.meas"), envir = environment())
     
-    for(i in 1:length(datalist))
+    for(i in 1:length(data.list))
     {
         #Compute network measures
         net.meas[[i]] <- pbapply::pbsapply(X = rand.list[[i]], FUN = semnetmeas, cl = cl)
@@ -132,7 +112,7 @@ randnet.test <- function (..., iter, cores)
     names(res) <- name
     
     #Compute significance tests
-    for(i in 1:length(datalist))
+    for(i in 1:length(data.list))
     {
         sig.mat <- matrix(0, nrow = 3, ncol = 3)
         row.names(sig.mat) <- c("ASPL","CC","Q")
@@ -143,7 +123,7 @@ randnet.test <- function (..., iter, cores)
         sig.mat[,"SD.rand"] <- round(apply(net.meas[[i]],1,sd),4)
         
         #Compute semantic network measures for network
-        meas <- semnetmeas(datalist[[i]])
+        meas <- semnetmeas(listdata[[i]])
         
         ##ASPL
         z.aspl <- (meas["ASPL"] - sig.mat["ASPL","M.rand"]) / sig.mat["ASPL","SD.rand"]
